@@ -7,7 +7,7 @@ knitr::opts_chunk$set(
 library(CDMConnector)
 if (Sys.getenv("EUNOMIA_DATA_FOLDER") == "") Sys.setenv("EUNOMIA_DATA_FOLDER" = tempdir())
 if (!dir.exists(Sys.getenv("EUNOMIA_DATA_FOLDER"))) dir.create(Sys.getenv("EUNOMIA_DATA_FOLDER"))
-if (!eunomia_is_available()) downloadEunomiaData()
+if (!eunomiaIsAvailable()) downloadEunomiaData()
 
 ## ----message=FALSE, warning=FALSE, echo=FALSE---------------------------------
 library(CDMConnector)
@@ -16,11 +16,11 @@ library(dplyr)
 library(tidyr)
 
 db <- DBI::dbConnect(duckdb::duckdb(), 
-                     dbdir = CDMConnector::eunomia_dir())
-cdm <- cdm_from_con(
+                     dbdir = CDMConnector::eunomiaDir())
+cdm <- cdmFromCon(
   con = db,
-  cdm_schema = "main", 
-  write_schema = "main"
+  cdmSchema = "main", 
+  writeSchema = "main"
 )
 
 ## -----------------------------------------------------------------------------
