@@ -2,9 +2,7 @@ test_that("restrict to codes in use", {
   cdm <- mockVocabRef("database")
   startCl <- list(a = c(4,5,6),
                   b = c(1,2))
-  endCl <- restrictToCodesInUse(startCl, cdm)
-  endCl2 <- subsetToCodesInUse(startCl, cdm)
-  expect_identical(endCl, endCl2)
+  endCl <- subsetToCodesInUse(startCl, cdm)
 
   expect_true(all(c(4,5) %in% endCl[["a"]]))
   expect_false(c(6) %in% endCl[["a"]])
@@ -13,13 +11,13 @@ test_that("restrict to codes in use", {
 
 
   # restrict on minimum count
-  endCl2 <- restrictToCodesInUse(startCl, cdm, minimumCount = 300)
+  endCl2 <- subsetToCodesInUse(startCl, cdm, minimumCount = 300)
   expect_true(c(4) %in% endCl2[["a"]])
   expect_false(c(5) %in% endCl2[["a"]])
   expect_false(c(6) %in% endCl2[["a"]])
 
   # none with sufficient count
-  endCl3 <- restrictToCodesInUse(startCl, cdm, minimumCount = 500)
+  endCl3 <- subsetToCodesInUse(startCl, cdm, minimumCount = 500)
   expect_true(length(endCl3) == 0)
 
 })
